@@ -1,6 +1,6 @@
 import uuid
 
-from azure.kusto.data._telemetry import KustoTracingAttributes
+from azure.kusto.data._telemetry import Span
 
 from .descriptors import DescriptorBase
 from .ingestion_properties import IngestionProperties
@@ -16,7 +16,7 @@ class IngestTracingAttributes:
 
     @classmethod
     def set_ingest_descriptor_attributes(cls, descriptor: DescriptorBase, ingestion_properties: IngestionProperties) -> None:
-        KustoTracingAttributes.add_attributes(tracing_attributes={**ingestion_properties.get_tracing_attributes(), **descriptor.get_tracing_attributes()})
+        Span.add_attributes(tracing_attributes={**ingestion_properties.get_tracing_attributes(), **descriptor.get_tracing_attributes()})
 
     @classmethod
     def create_enqueue_request_attributes(cls, queue_name: str, source_id: uuid.UUID) -> dict:
